@@ -1,7 +1,7 @@
-__version__ = '1.1.0'
+__version__ = '1.1.1'
 __author__ = 'ZephyrOff  (Alexandre Pajak)'
 __descriptor__ = 'Générateur de menu à touches fléchées'
 __lastupdate__ = '24/08/2022'
-__releasenote__ = 'Patch terminal_mode'
+__releasenote__ = 'Patch windows terminal mode'
 
 from .menu import *
\ No newline at end of file
